FileSystemService

Trait FileSystemService 

pub trait FileSystemService {
    // Required methods
    fn get_file_info(&self, path: &str) -> FugaResult<FileInfo>;
    fn get_abs_path(&self, path: &str) -> FugaResult<String>;
    fn get_file_type(&self, path: &str) -> TargetType;
    fn copy_items(&self, src: &str, dst: &str) -> FugaResult<()>;
    fn move_items(&self, src: &str, dst: &str) -> FugaResult<()>;
    fn link_items(&self, src: &str, dst: &str) -> FugaResult<()>;
}
Trait for file system operations

Required Methods

fn get_file_info(&self, path: &str) -> FugaResult<FileInfo>

Get comprehensive file information

fn get_abs_path(&self, path: &str) -> FugaResult<String>

Get the absolute path of a file or directory

fn get_file_type(&self, path: &str) -> TargetType

Get the type of the target file or directory

fn copy_items(&self, src: &str, dst: &str) -> FugaResult<()>

Copy files or directories

fn move_items(&self, src: &str, dst: &str) -> FugaResult<()>

Move files or directories

Create symbolic links

Implementors